==> js-api-creator-1.0.1.tgz: package/es/apiCreator.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _Object$keys from "babel-runtime/core-js/object/keys";
import _Object$assign from "babel-runtime/core-js/object/assign";
import requestAPI from './xhrApi';

var isFormData = function isFormData(payload) {

	if (typeof FormData !== "undefined") {
		return payload.constructor == new FormData().constructor;
	}

	return typeof payload == "function";
};

var Builder = function Builder(apiJson, options) {
	//Url and param builder..
	var apiOptions = function apiOptions(_method, requestUrl, parameters, queryParameters) {

		var userParams = parameters;
		var isFormDataParams = isFormData(parameters);
		if (!isFormDataParams) {
			userParams = _Object$assign({}, parameters); // to address re-back call ajax parameters keeping..
			if (_Object$keys(parameters).length) {
				var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
				for (var i = 0, len = propsToUrl.length; i < len; i++) {
					var prop = propsToUrl[i];
					var paramKey = prop.replace(':', '');
					if (prop.charAt(0) === ':' && userParams.hasOwnProperty(paramKey)) {
						var value = userParams[paramKey];
						requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
						requestUrl = requestUrl.replace(prop + '/', value ? value + '/' : '');
						delete userParams[paramKey];
					}
				}
			}
		}

		var defaultParams = _Object$assign({}, queryParameters, options.defaultParams(_method));
		var gobalParamsToUrl = '';
		var count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += "&" + prop + "=" + defaultParams[prop];
				break;
			}
			gobalParamsToUrl += prop + "=" + defaultParams[prop];
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';

		if (!isFormDataParams) {
			var length = userParams ? _Object$keys(userParams).length : 0;
			userParams = length > 0 ? userParams : null;
		}

		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl,
			param: userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = function httpConnection(ajaxmethod) {
		return function (url, userPayload, userQueryStringParams, success, failure, progressReport) {

			var ajaxcall = function ajaxcall() {

				var authHeaders = options.authHeaders;
				var headers = authHeaders ? authHeaders(ajaxmethod) : null;

				if (typeof userPayload == 'function') {

					var apioptions = apiOptions(ajaxmethod, url, {});
					return requestAPI(apioptions.url, headers)[ajaxmethod](apioptions.param, success).then(userPayload, userQueryStringParams);
				}

				if (typeof userQueryStringParams == 'function') {
					var apioptions = apiOptions(ajaxmethod, url, userPayload || {});
					return requestAPI(apioptions.url, headers)[ajaxmethod](apioptions.param, failure).then(userQueryStringParams, success);
				}

				var apioptions = apiOptions(ajaxmethod, url, userPayload || {}, userQueryStringParams);
				return requestAPI(apioptions.url, headers)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
			};

			return ajaxcall();
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {

		var api = prop;
		var apivalue = apiJson[prop];

		var apiurl = apivalue.url;
		var apimethod = apivalue.method;

		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {

				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);

				/*if (apiFragment.indexOf('+++') != -1) {
    	apiFragment = apiFragment.replace('+++', '');
    	lastObj[apiFragment] = httpConnection('put').bind(null, apiurl);
    } 
    else if (apiFragment.indexOf('++') != -1) {
    	apiFragment = apiFragment.replace('++', '');
    	lastObj[apiFragment] = httpConnection('post').bind(null, apiurl);
    } 
    else if (apiFragment.indexOf('>>>') != -1) {
    	apiFragment = apiFragment.replace('>>>', '');
    	lastObj[apiFragment] = httpConnection('postAsParams').bind(null, apiurl);
    }
    else if (apiFragment.indexOf('--') != -1) {
    	apiFragment = apiFragment.replace('--', '');
    	lastObj[apiFragment] = httpConnection('delete').bind(null, apiurl);
    } 
    else if (apiFragment.indexOf('>>') != -1) {
    	apiFragment = apiFragment.replace('>>', '');
    	lastObj[apiFragment] = httpConnection('downloadFile').bind(null, apiurl);
    }
    else {
    	lastObj[apiFragment] = httpConnection('get').bind(null, apiurl);
    }*/
			}

			if (apiFragment && typeof lastObj[apiFragment] !== 'undefined') {
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

var _class = function () {
	function _class(prefixUrl, defaultParams, authHeaders) {
		_classCallCheck(this, _class);

		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
	}

	_createClass(_class, [{
		key: "create",
		value: function create(javaApiList, name) {

			var defaultParams = this.defaultParams ? this.defaultParams.bind(null, name) : null;
			var prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null, name) : '';
			var authHeaders = this.authHeaders ? this.authHeaders.bind(null, name) : null;

			return Builder(javaApiList || {}, { defaultParams: defaultParams, prefixUrl: prefixUrl, authHeaders: authHeaders });
		}
	}]);

	return _class;
}();

export default _class;

==> js-api-creator-1.0.2.tgz: package/es/apiCreator.js <==
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _Object$keys from "babel-runtime/core-js/object/keys";
import _Object$assign from "babel-runtime/core-js/object/assign";
import requestAPI from './xhrApi';

var isFormData = function isFormData(payload) {

	if (typeof FormData !== "undefined") {
		return payload.constructor == new FormData().constructor;
	}

	return typeof payload == "function";
};

var Builder = function Builder(apiJson, options) {
	//Url and param builder..
	var apiOptions = function apiOptions(_method, requestUrl, parameters, queryParameters) {

		var userParams = parameters;
		var isFormDataParams = isFormData(parameters);
		if (!isFormDataParams) {
			userParams = _Object$assign({}, parameters); // to address re-back call ajax parameters keeping..
			if (_Object$keys(parameters).length) {
				var propsToUrl = requestUrl.split('/'); // helps to some parameter to url...
				for (var i = 0, len = propsToUrl.length; i < len; i++) {
					var prop = propsToUrl[i];
					var paramKey = prop.replace(':', '');
					if (prop.charAt(0) === ':' && userParams.hasOwnProperty(paramKey)) {
						var value = userParams[paramKey];
						requestUrl = requestUrl.replace('/' + prop, value ? '/' + value : '');
						requestUrl = requestUrl.replace(prop + '/', value ? value + '/' : '');
						delete userParams[paramKey];
					}
				}
			}
		}

		var defaultParams = _Object$assign({}, queryParameters, options.defaultParams(_method));
		var gobalParamsToUrl = '';
		var count = 0;
		for (var prop in defaultParams) {
			if (count > 0) {
				gobalParamsToUrl += "&" + prop + "=" + defaultParams[prop];
				break;
			}
			gobalParamsToUrl += prop + "=" + defaultParams[prop];
			count = 1;
		}

		gobalParamsToUrl = gobalParamsToUrl ? '?' + gobalParamsToUrl : '';

		if (!isFormDataParams) {
			var length = userParams ? _Object$keys(userParams).length : 0;
			userParams = length > 0 ? userParams : null;
		}

		return {
			url: options.prefixUrl(_method) + requestUrl + gobalParamsToUrl,
			param: userParams
		};
	};

	//url - bind arguments not from user..
	var httpConnection = function httpConnection(ajaxmethod) {
		return function (url) {
			var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
			var _options$payload = options.payload,
			    payload = _options$payload === undefined ? {} : _options$payload,
			    headers = options.headers,
			    parameters = options.parameters,
			    success = options.success,
			    failure = options.failure,
			    progressReport = options.progressReport;


			var authHeaders = options.authHeaders;
			var urlHeaders = authHeaders ? authHeaders(ajaxmethod) : null;
			urlHeaders = urlHeaders ? _Object$assign(urlHeaders, headers) : headers;

			var apioptions = apiOptions(ajaxmethod, url, payload, parameters);
			return requestAPI(apioptions.url, urlHeaders)[ajaxmethod](apioptions.param, progressReport).then(success, failure);
		};
	};

	//auto api functions creation...
	var userAPIS = {};
	for (var prop in apiJson) {

		var api = prop;
		var apivalue = apiJson[prop];

		var apiurl = apivalue.url;
		var apimethod = apivalue.method;

		//var apiFragments = api.split('/');
		var apiFragments = api.split('.');
		var lastObj = userAPIS;

		for (var j = 0; j < apiFragments.length; j++) {
			var apiFragment = apiFragments[j];
			if (apiFragment.indexOf(':') != -1) {
				continue; //Skipping this !api
			}

			if (apiFragment && typeof lastObj[apiFragment] === 'undefined') {
				lastObj[apiFragment] = httpConnection(apimethod).bind(null, apiurl);
			}

			if (apiFragment && typeof lastObj[apiFragment] !== 'undefined') {
				lastObj = lastObj[apiFragment];
			}
		}
	}

	return userAPIS;
};

var _class = function () {
	function _class(prefixUrl, defaultParams, authHeaders) {
		_classCallCheck(this, _class);

		this.prefixUrl = prefixUrl;
		this.defaultParams = defaultParams;
		this.authHeaders = authHeaders;
	}

	_createClass(_class, [{
		key: "create",
		value: function create(javaApiList, name) {

			var defaultParams = this.defaultParams ? this.defaultParams.bind(null, name) : null;
			var prefixUrl = this.prefixUrl ? this.prefixUrl.bind(null, name) : '';
			var authHeaders = this.authHeaders ? this.authHeaders.bind(null, name) : null;

			return Builder(javaApiList || {}, { defaultParams: defaultParams, prefixUrl: prefixUrl, authHeaders: authHeaders });
		}
	}]);

	return _class;
}();

export default _class;
